# import caipyra - [Caipyra Event Poem](http://caipyra.python.org.br/)
[![PyPI version](https://badge.fury.io/py/caipyra.svg)](https://badge.fury.io/py/caipyra)
[![Build Status](https://travis-ci.org/jtemporal/import_caipyra.svg?branch=master)](https://travis-ci.org/jtemporal/import_caipyra)
[![License: MIT](https://img.shields.io/badge/License-MIT-blue.svg)](https://opensource.org/licenses/MIT)

## Installation
```
pip install caipyra
```

## Usage

```
>>> from caipyra import this

Caipyra por Humberto Diógenes

Continue (Y/n)? y

Na minha terra é matuto
Que é quem veio do mato
Ou beradêro, do rio
mermo na beira
Na do Andrews é capiau
Mas aqui é caipira

Continue (Y/n)? n

>>> this.link()  # abre a apresentação do Import Caipyra no youtube

>>> from caipyra import java
É mentiiiira!!!
>>>
```

## Contributing
PRs are welcome, if you have any questions don't be afraid to open an issue.

And remember: Always pull before pushing =)
